@@ -238,17 +238,18 @@ void annotatemore_init(int myflags,
     init_annotation_definitions();
 }
 
-void annotatemore_open(char *fname)
+void annotatemore_open(const char *fname)
 {
     int ret;
     char *tofree = NULL;
 
+    if (!fname)
+	fname = config_getstring(IMAPOPT_ANNOTATION_DB_PATH);
+
     /* create db file name */
     if (!fname) {
-	fname = xmalloc(strlen(config_dir)+sizeof(FNAME_ANNOTATIONS));
-	tofree = fname;
-	strcpy(fname, config_dir);
-	strcat(fname, FNAME_ANNOTATIONS);
+	tofree = strconcat(config_dir, FNAME_ANNOTATIONS, (char *)NULL);
+	fname = tofree;
     }
 
     ret = (DB->open)(fname, CYRUSDB_CREATE, &anndb);
@@ -258,7 +259,7 @@ void annotatemore_open(char *fname)
 	fatal("can't read annotations file", EC_TEMPFAIL);
     }    
 
-    if (tofree) free(tofree);
+    free(tofree);
 
     annotate_dbopen = 1;
 }
@@ -1717,7 +1718,7 @@ static int annotation_set_mailboxopt(const char *int_mboxname,
 {
     struct mailbox *mailbox = NULL;
     int flag = 0, r = 0, i;
-    unsigned long oldopts;
+    unsigned long newopts;
 
     /* Check entry */
     for (i = 0; annotate_mailbox_flags[i].name; i++) {
@@ -1739,22 +1740,23 @@ static int annotation_set_mailboxopt(const char *int_mboxname,
     r = mailbox_open_iwl(int_mboxname, &mailbox);
     if (r) return r;
 
-    oldopts = mailbox->i.options;
+    newopts = mailbox->i.options;
 
     if (!strcmp(entry->shared.value, "true")) {
-	mailbox->i.options |= flag;
+	newopts |= flag;
     } else {
-	mailbox->i.options &= ~flag;
+	newopts &= ~flag;
     }
 
-    if (oldopts != mailbox->i.options) {
+    /* only commit if there's been a change */
+    if (mailbox->i.options != newopts) {
 	mailbox_index_dirty(mailbox);
-	r = mailbox_commit(mailbox);
+	mailbox->i.options = newopts;
     }
 
     mailbox_close(&mailbox);
 
-    return r;
+    return 0;
 }
 
 const struct annotate_st_entry server_entries[] =
